@@ -4,9 +4,16 @@
 bool search_mode_is_enabled = false;
 struct wstring *search_mode_text_input = NULL;
 static bool paint_it_black = true;
+static volatile bool newsraft_has_successfully_initialized_curses = false;
 
 pthread_mutex_t interface_lock = PTHREAD_MUTEX_INITIALIZER;
 
+bool
+curses_is_running(void)
+{
+	return newsraft_has_successfully_initialized_curses;
+}
+
 static bool
 obtain_list_menu_size(size_t *width, size_t *height)
 {
@@ -15,11 +22,9 @@ obtain_list_menu_size(size_t *width, size_t *height)
 		FAIL("Failed to get width of the terminal!");
 		return false;
 	}
-	// It is necessary that a counter field of 9 characters width and at least
-	// some nonzero width of the status field fit in the screen.
 	// This is really critical! You will get integer overflow if terminal_width
-	// is less than 10. You have been warned.
-	if (terminal_width < 10) {
+	// is less than 12. You have been warned.
+	if (terminal_width < 12) {
 		FAIL("Terminal is too narrow!");
 		return false;
 	}
@@ -72,8 +77,36 @@ curses_init(void)
 		WARN("Initialization of curses color structures failed!");
 	} else {
 		paint_it_black = false; // Some iridescent sensation at last!
+		INFO("Maximum number of colors: %d", COLORS);
+		INFO("Maximum number of color pairs: %d", COLOR_PAIRS);
 	}
 	INFO("The value of KEY_RESIZE code is %d.", KEY_RESIZE);
+	newsraft_has_successfully_initialized_curses = true;
+	return true;
+}
+
+void
+curses_stop(void)
+{
+	endwin();
+}
+
+bool
+run_menu_loop(void)
+{
+	struct timespec idling = {0, 100000000}; // 0.1 seconds
+	struct menu_state *menu = setup_menu(&sections_menu_loop, NULL, NULL, 0, MENU_NORMAL);
+	if (menu == NULL) {
+		return false;
+	}
+	while (they_want_us_to_stop == false) {
+		menu = menu->run(menu);
+		if (menu == NULL) {
+			break; // TODO: don't stop feed downloader?
+			nanosleep(&idling, NULL); // Avoids CPU cycles waste while awaiting termination
+			menu = setup_menu(&sections_menu_loop, NULL, NULL, 0, MENU_DISABLE_SETTINGS);
+		}
+	}
 	return true;
 }
 
@@ -99,9 +132,6 @@ resize_handler(void)
 	if (status_recreate_unprotected() == false) {
 		goto error;
 	}
-	if (counter_recreate_unprotected() == false) {
-		goto error;
-	}
 	if (is_current_menu_a_pager() == true) {
 		refresh_pager_menu();
 	}
@@ -109,7 +139,7 @@ resize_handler(void)
 	pthread_mutex_unlock(&interface_lock);
 	return INPUT_ERROR;
 error:
-	tell_program_to_terminate_safely_and_quickly(0);
+	they_want_us_to_stop = true;
 	pthread_mutex_unlock(&interface_lock);
 	return INPUT_QUIT_HARD;
 }
