@@ -156,7 +156,7 @@ copy_feed_to_global_section(const struct feed_entry *feed)
 		return NULL;
 	}
 	sections[0].feeds[feed_index]->unread_count  = new_unread_count;
-	sections[0].feeds[feed_index]->download_date = db_get_date_from_feeds_table(feed->link, "download_date", 13);
+	sections[0].feeds[feed_index]->update_date = db_get_date_from_feeds_table(feed->link, "update_date", 11);
 	return sections[0].feeds[feed_index];
 }
 
@@ -200,34 +200,27 @@ refresh_unread_items_count_of_all_sections(void)
 bool
 purge_abandoned_feeds(void)
 {
-	if (sections[0].feeds_count == 0) {
+	char *query = malloc(sizeof(char) * (42 + sections[0].feeds_count * 2 + 100));
+	if (query == NULL || sections[0].feeds_count == 0) {
+		free(query);
 		return true;
 	}
-	struct string *query = crtas("DELETE FROM items WHERE feed_url NOT IN (?", 42);
-	if (query == NULL) {
-		return false;
-	}
+	strcpy(query, "DELETE FROM items WHERE feed_url NOT IN (?");
 	for (size_t i = 1; i < sections[0].feeds_count; ++i) {
-		if (catas(query, ",?", 2) == false) {
-			free_string(query);
-			return false;
-		}
+		strcat(query, ",?");
 	}
-	if (catcs(query, ')') == false) {
-		free_string(query);
-		return false;
-	}
-	sqlite3_stmt *res = db_prepare(query->ptr, query->len + 1);
+	strcat(query, ")");
+	sqlite3_stmt *res = db_prepare(query, strlen(query) + 1);
 	if (res == NULL) {
-		free_string(query);
+		free(query);
 		return false;
 	}
 	for (size_t i = 0; i < sections[0].feeds_count; ++i) {
 		db_bind_string(res, i + 1, sections[0].feeds[i]->link);
 	}
-	const bool status = sqlite3_step(res) == SQLITE_DONE ? true : false;
+	bool status = sqlite3_step(res) == SQLITE_DONE ? true : false;
 	sqlite3_finalize(res);
-	free_string(query);
+	free(query);
 	return status;
 }
 
@@ -253,17 +246,34 @@ free_sections(void)
 	free(sections);
 }
 
+bool
+start_updating_all_feeds_and_wait_finish(void)
+{
+	queue_updates(sections[0].feeds, sections[0].feeds_count);
+	queue_wait_finish();
+	return true;
+}
+
+bool
+print_unread_items_count(void)
+{
+	int64_t count = db_count_items(sections[0].feeds, sections[0].feeds_count, true);
+	fprintf(stdout, "%" PRId64 "\n", count);
+	fflush(stdout);
+	return true;
+}
+
 void
 process_auto_updating_feeds(void)
 {
 	time_t now = time(NULL);
 	if (now > 0) {
 		for (size_t i = 0; i < sections[0].feeds_count; ++i) {
-			size_t download = sections[0].feeds[i]->download_date;
-			size_t age = (size_t)now > download ? now - download : 0;
+			size_t last_try = sections[0].feeds[i]->update_date;
+			size_t age = (size_t)now > last_try ? now - last_try : 0;
 			size_t reload_period = get_cfg_uint(&sections[0].feeds[i]->cfg, CFG_RELOAD_PERIOD) * 60;
 			if (reload_period > 0 && age > reload_period) {
-				update_feeds(sections[0].feeds + i, 1);
+				queue_updates(sections[0].feeds + i, 1);
 			}
 		}
 	}
@@ -279,10 +289,11 @@ sections_menu_loop(struct menu_state *m)
 	m->write_action = &list_menu_writer;
 	m->entry_format = get_cfg_wstring(NULL, CFG_MENU_SECTION_ENTRY_FORMAT);
 	if (!(m->flags & MENU_DISABLE_SETTINGS)) {
-		if (get_cfg_bool(NULL, CFG_SECTIONS_MENU_PARAMOUNT_EXPLORE) && get_items_count_of_feeds(sections[0].feeds, sections[0].feeds_count)) {
-			return setup_menu(&items_menu_loop, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE);
+		// Don't set the menu names here because it's redundant!
+		if (get_cfg_bool(NULL, CFG_SECTIONS_MENU_PARAMOUNT_EXPLORE) && db_count_items(sections[0].feeds, sections[0].feeds_count, false)) {
+			return setup_menu(&items_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE);
 		} else if (sections_count == 1) {
-			return setup_menu(&feeds_menu_loop, sections[0].feeds, sections[0].feeds_count, MENU_SWALLOW);
+			return setup_menu(&feeds_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_SWALLOW);
 		}
 	}
 	refresh_unread_items_count_of_all_sections();
@@ -298,16 +309,16 @@ sections_menu_loop(struct menu_state *m)
 			case INPUT_MARK_UNREAD:     mark_feeds_read(sections[m->view_sel].feeds, sections[m->view_sel].feeds_count, false); break;
 			case INPUT_MARK_READ_ALL:   mark_feeds_read(sections[0].feeds, sections[0].feeds_count, true);                      break;
 			case INPUT_MARK_UNREAD_ALL: mark_feeds_read(sections[0].feeds, sections[0].feeds_count, false);                     break;
-			case INPUT_RELOAD:          update_feeds(sections[m->view_sel].feeds, sections[m->view_sel].feeds_count);           break;
-			case INPUT_RELOAD_ALL:      update_feeds(sections[0].feeds, sections[0].feeds_count);                               break;
+			case INPUT_RELOAD:          queue_updates(sections[m->view_sel].feeds, sections[m->view_sel].feeds_count);          break;
+			case INPUT_RELOAD_ALL:      queue_updates(sections[0].feeds, sections[0].feeds_count);                              break;
 			case INPUT_ENTER:
-				return setup_menu(&feeds_menu_loop, sections[m->view_sel].feeds, sections[m->view_sel].feeds_count, MENU_NO_FLAGS);
+				return setup_menu(&feeds_menu_loop, sections[m->view_sel].name, sections[m->view_sel].feeds, sections[m->view_sel].feeds_count, MENU_NORMAL);
 			case INPUT_TOGGLE_EXPLORE_MODE:
-				return setup_menu(&items_menu_loop, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE);
+				return setup_menu(&items_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE);
 			case INPUT_APPLY_SEARCH_MODE_FILTER:
-				return setup_menu(&items_menu_loop, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE | MENU_USE_SEARCH);
+				return setup_menu(&items_menu_loop, NULL, sections[0].feeds, sections[0].feeds_count, MENU_IS_EXPLORE | MENU_USE_SEARCH);
 			case INPUT_STATUS_HISTORY_MENU:
-				return setup_menu(&status_pager_loop, NULL, 0, MENU_NO_FLAGS);
+				return setup_menu(&status_pager_loop, NULL, NULL, 0, MENU_NORMAL);
 			case INPUT_QUIT_SOFT:
 			case INPUT_QUIT_HARD:
 				return NULL;
